@@ -89,13 +89,13 @@ KJezzball::KJezzball()
 
     // create timers
     m_nextLevelTimer = new TQTimer( this, "m_nextLevelTimer" );
-    connect( m_nextLevelTimer, TQT_SIGNAL(timeout()), TQT_TQOBJECT(this), TQT_SLOT(switchLevel()) );
+    connect( m_nextLevelTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(switchLevel()) );
 
     m_gameOverTimer = new TQTimer( this, "m_gameOverTimer" );
-    connect( m_gameOverTimer, TQT_SIGNAL(timeout()), TQT_TQOBJECT(this), TQT_SLOT(gameOverNow()) );
+    connect( m_gameOverTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(gameOverNow()) );
 
     m_timer = new TQTimer( this, "m_timer" );
-    connect( m_timer, TQT_SIGNAL(timeout()), TQT_TQOBJECT(this), TQT_SLOT(second()) );
+    connect( m_timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(second()) );
 
     // create demo game
     createLevel( 1 );
@@ -119,23 +119,23 @@ KJezzball::~KJezzball()
  */
 void KJezzball::initXMLUI()
 {
-    m_newAction = KStdGameAction::gameNew( TQT_TQOBJECT(this), TQT_SLOT(newGame()), actionCollection() );
+    m_newAction = KStdGameAction::gameNew( this, TQ_SLOT(newGame()), actionCollection() );
     // AB: originally KBounce/KJezzball used Space for new game - but Ctrl+N is
     // default. We solve this by providing space as an alternative key
     TDEShortcut s = m_newAction->shortcut();
     s.append(KKeySequence(TQKeySequence(Key_Space)));
     m_newAction->setShortcut(s);
 
-    KStdGameAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection() );
-    KStdGameAction::highscores(TQT_TQOBJECT(this), TQT_SLOT(showHighscore()), actionCollection() );
-    m_pauseButton = KStdGameAction::pause(TQT_TQOBJECT(this), TQT_SLOT(pauseGame()), actionCollection());
-    KStdGameAction::end(TQT_TQOBJECT(this), TQT_SLOT(closeGame()), actionCollection());
-    KStdGameAction::configureHighscores(TQT_TQOBJECT(this), TQT_SLOT(configureHighscores()),actionCollection());
+    KStdGameAction::quit(this, TQ_SLOT(close()), actionCollection() );
+    KStdGameAction::highscores(this, TQ_SLOT(showHighscore()), actionCollection() );
+    m_pauseButton = KStdGameAction::pause(this, TQ_SLOT(pauseGame()), actionCollection());
+    KStdGameAction::end(this, TQ_SLOT(closeGame()), actionCollection());
+    KStdGameAction::configureHighscores(this, TQ_SLOT(configureHighscores()),actionCollection());
 
-    new TDEAction( i18n("&Select Background Folder..."), 0, TQT_TQOBJECT(this), TQT_SLOT(selectBackground()),
+    new TDEAction( i18n("&Select Background Folder..."), 0, this, TQ_SLOT(selectBackground()),
                        actionCollection(), "background_select" );
     m_backgroundShowAction =
-        new TDEToggleAction( i18n("Show &Backgrounds"), 0, TQT_TQOBJECT(this), TQT_SLOT(showBackground()),
+        new TDEToggleAction( i18n("Show &Backgrounds"), 0, this, TQ_SLOT(showBackground()),
                            actionCollection(), "background_show" );
     m_backgroundShowAction->setCheckedState(i18n("Hide &Backgrounds"));
     m_backgroundShowAction->setEnabled( !m_backgroundDir.isEmpty() );
@@ -400,9 +400,9 @@ void KJezzball::createLevel( int level )
 
     m_gameWidget->show();
     m_layout->addWidget( m_gameWidget, 0, 0 );
-    connect( m_gameWidget, TQT_SIGNAL(died()), TQT_TQOBJECT(this), TQT_SLOT(died()) );
-    connect( m_gameWidget, TQT_SIGNAL(newPercent(int)), TQT_TQOBJECT(this), TQT_SLOT(newPercent(int)) );
-    connect( m_soundAction, TQT_SIGNAL(toggled(bool)), m_gameWidget, TQT_SLOT(setSound(bool)) );
+    connect( m_gameWidget, TQ_SIGNAL(died()), this, TQ_SLOT(died()) );
+    connect( m_gameWidget, TQ_SIGNAL(newPercent(int)), this, TQ_SLOT(newPercent(int)) );
+    connect( m_soundAction, TQ_SIGNAL(toggled(bool)), m_gameWidget, TQ_SLOT(setSound(bool)) );
 
     // update displays
     m_level.lifes = level+1;
