@@ -63,7 +63,7 @@ class TDEConfig;
 //
 
 class QReversiGame : public TQObject, public Game {
- Q_OBJECT
+ TQ_OBJECT
   
 
  public:
