@@ -9,7 +9,7 @@
  */
 class MPBoard : public TQWidget
 {
- Q_OBJECT
+ TQ_OBJECT
   
 
  public:
