@@ -23,7 +23,7 @@
 #include <kdialogbase.h>
 #include <tqmap.h> // TODO: remove - it is in kcarddialog.cpp now; left here for source compatibility
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 class TQIconViewItem;
 
 class TDEConfig;
@@ -87,7 +87,7 @@ class KCardDialogPrivate;
  * @author Martin Heni <martin@heni-online.de>
  * @version $Id$
  */
-class KDE_EXPORT KCardDialog : public KDialogBase
+class TDE_EXPORT KCardDialog : public KDialogBase
 {
   TQ_OBJECT
   
