@@ -174,7 +174,7 @@ class KMessageServerPrivate;
 */
 class KMessageServer : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -476,7 +476,7 @@ private:
 */
 class KMessageServerSocket : public TQServerSocket
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
